@@ -18,8 +18,6 @@
 #include <QCoreApplication>
 #include <QByteArray>
 #include <QUrl>
-#include <Phonon/MediaObject>
-#include <Phonon/AudioOutput>
 #include <QProcess>
 #include <QDBusConnection>
 #include <QDBusInterface>
@@ -564,16 +562,10 @@ void burniso2cd::printOutErase(int, QProcess::ExitStatus) {
   is_erasing = false;
   int valore_uscita = erase->exitCode();
 if(valore_uscita == 0) {
-  if (playcheckbox->isChecked()) {
-    play_success();
-  }
   QMessageBox::information(this, "AcetoneISO",tr("Process Succesfully Finished!"));
   QWidget::close ();
 }
 else {
-  if (playcheckbox->isChecked()) {
-    play_error();
-  }
   QMessageBox::critical(this, "AcetoneISO","Process Error Code: " + QString::number(valore_uscita) );
 }
 }
@@ -583,7 +575,6 @@ void burniso2cd::enable_buttons() {
   start->setEnabled(true);
   devices_combo->setEnabled(true);
   eject->setEnabled(true);
-  playcheckbox->setEnabled(true);
   simulation_checkbox->setEnabled(true);
   combo_speed->setEnabled(true);
   push_select_image->setEnabled(true);
@@ -593,7 +584,6 @@ void burniso2cd::disable_buttons() {
   start->setEnabled(false);
   devices_combo->setEnabled(false);
   eject->setEnabled(false);
-  playcheckbox->setEnabled(false);
   simulation_checkbox->setEnabled(false);
   combo_speed->setEnabled(false);
   push_select_image->setEnabled(false);
@@ -601,6 +591,7 @@ void burniso2cd::disable_buttons() {
 
 
 void burniso2cd::play_success() {
+  /*
   Phonon::MediaObject *mediaObject;	
   Phonon::AudioOutput *audioOutput; 
   Phonon::Path path;
@@ -610,9 +601,11 @@ void burniso2cd::play_success() {
   QString file(":/audio/success.ogg");
   mediaObject->setCurrentSource(Phonon::MediaSource(file));
   mediaObject->play();
+  */
 }
 
 void burniso2cd::play_error() {
+  /*
   Phonon::MediaObject *mediaObject;	
   Phonon::AudioOutput *audioOutput; 
   Phonon::Path path;
@@ -622,6 +615,7 @@ void burniso2cd::play_error() {
   QString file(":/audio/error.ogg");
   mediaObject->setCurrentSource(Phonon::MediaSource(file));
   mediaObject->play();
+  */
 }
 
 
