@@ -20,8 +20,6 @@
 #define BURN_ISO2CD_H
 #include <QFile>
 #include <QUrl>
-#include <Phonon/MediaObject>
-#include <Phonon/AudioOutput>
 #include <QProcess>
 #include <QByteArray>
 #include <QDialog>
