@@ -20,8 +20,7 @@ void acetoneiso::connections() {
     connect( actionConvert_MacOs_Image_2, SIGNAL ( triggered() ), this, SLOT ( macimg() ) );
     connect( pushButton, SIGNAL( clicked() ), this, SLOT( mount() ) ); 
     connect( pushButton_2, SIGNAL( clicked() ), this, SLOT( umount() ) ); 
-    
-    connect( pushButton_3, SIGNAL( clicked() ), this, SLOT( clear_history() ) ); 
+ 
     connect( pushButton_6, SIGNAL( clicked() ), this, SLOT( hide_process_display() ) ); 
     
     connect(actionMake_a_small_donation, SIGNAL( triggered() ), this, SLOT( paypal() ) );
@@ -120,7 +119,19 @@ void acetoneiso::connections() {
     connect(erase_combobox_action, SIGNAL( clicked() ), this, SLOT( erase_media() ) );
     connect(pushButton_7, SIGNAL( clicked() ), this, SLOT( burniso2_cd() ) );
 
-  connect(listWidget_2, SIGNAL( itemSelectionChanged() ), this, SLOT( mountdisplayClicked() ) );
+    connect(listWidget_2, SIGNAL( itemSelectionChanged() ), this, SLOT( mountdisplayClicked() ) );
+    
+    
+    //first tab buttons
+    connect(clearHistoryButton, SIGNAL( clicked() ), this, SLOT(clear_history() ) );   
+    connect( removeHistoryButton, SIGNAL( clicked() ), this, SLOT(removeHistory() ) );    
+    
+    
+    //torrent
+    connect( torrentWidget , SIGNAL( itemSelectionChanged () ), this, SLOT( itemTorrentChanged() ) ); 
+    connect( tabWidget , SIGNAL( currentChanged ( int ) ), this, SLOT( mainTabChanged(int) ) ); 
+    connect( openTorrentButton, SIGNAL( clicked() ), this, SLOT( openTorrent() ) ); 
+    connect(openUrlTorrentButton, SIGNAL( clicked() ), this, SLOT( openUrlTorrent() ) ); 
     
     
 }
