@@ -24,8 +24,6 @@
 #include <fcntl.h>
 #include <iostream>
 #include <QDebug>
-#include <Phonon/MediaObject>
-#include <Phonon/AudioOutput>
 #include "erase_dvd.h"
 
 /*
@@ -336,16 +334,10 @@ EJect.start("eject",QStringList()  << dev );
 
 int valore_uscita = erase->exitCode();
 if(valore_uscita == 0) {
-  if (playcheckbox->isChecked()) {
-    play_success();
-  }
   QMessageBox::information(this, "AcetoneISO",tr("Process Succesfully Finished!"));
   textBrowser->clear();
 }
 else {
-  if (playcheckbox->isChecked()) {
-    play_error();
-  }
   QMessageBox::critical(this, "AcetoneISO","Process Error Code: " + QString::number(valore_uscita) );
 }
 }
@@ -357,7 +349,6 @@ devices_combo->setEnabled(true);
 eject->setEnabled(true);
 radioButton->setEnabled(true);
 radioButton_2->setEnabled(true);
-playcheckbox->setEnabled(true);
 }
 //disabilita i bottoni
 void erasedvd::disable_buttons() {
@@ -366,11 +357,11 @@ devices_combo->setEnabled(false);
 eject->setEnabled(false);
 radioButton->setEnabled(false);
 radioButton_2->setEnabled(false); 
-playcheckbox->setEnabled(false);
 }
 
 
 void erasedvd::play_success() {
+  /*
 Phonon::MediaObject *mediaObject;	
 Phonon::AudioOutput *audioOutput; 
 Phonon::Path path;
@@ -380,9 +371,11 @@ path = Phonon::createPath(mediaObject, audioOutput);
 QString file(":/audio/success.ogg");
 mediaObject->setCurrentSource(Phonon::MediaSource(file));
 mediaObject->play();
+*/
 }
 
 void erasedvd::play_error() {
+  /*
 Phonon::MediaObject *mediaObject;	
 Phonon::AudioOutput *audioOutput; 
 Phonon::Path path;
@@ -392,6 +385,7 @@ path = Phonon::createPath(mediaObject, audioOutput);
 QString file(":/audio/error.ogg");
 mediaObject->setCurrentSource(Phonon::MediaSource(file));
 mediaObject->play();
+*/
 }
 
 
