@@ -16,7 +16,7 @@
 
 void acetoneiso::foldertoiso() {
   QFile mkisofs;
-  mkisofs.setFileName("/usr/bin/genisoimage");
+  mkisofs.setFileName("/usr/bin/xorrisofs");
   QDir Home = QDir::home();
   QFile file(Home.path() + "/.acetoneiso/acetoneiso.conf");
   file.open(QIODevice::ReadOnly);//lo apro in sola lettura
@@ -24,7 +24,7 @@ void acetoneiso::foldertoiso() {
   file.close();
   
   if (!mkisofs.exists()) {
-    QMessageBox::warning(this, "AcetoneISO::Warning!",tr("no genisoimage found in /usr/bin"));
+    QMessageBox::warning(this, "AcetoneISO::Warning!",tr("no xorrisofs found in /usr/bin"));
     return;
   }
 
@@ -37,7 +37,7 @@ void acetoneiso::foldertoiso() {
   QString iso;
   iso = fol.dirName();
 
-  QString fileName = QFileDialog::getSaveFileName(this, tr("AcetoneISO::Save ISO"), Home.path() , tr("Images (*.iso)"));
+  QString fileName = QFileDialog::getSaveFileName(this, tr("AcetoneISO::Save ISO"), Home.path() , tr("Images(*.iso)"));
 
   if ( fileName.isNull() ) {
     return;
@@ -51,7 +51,7 @@ void acetoneiso::foldertoiso() {
     MKisofs->setProcessChannelMode(QProcess::MergedChannels);
     connect(MKisofs, SIGNAL(readyReadStandardOutput()), SLOT(updateProgressDisplay_MKisofs() )); 
     connect(MKisofs, SIGNAL(finished(int, QProcess::ExitStatus)), this, SLOT(printOut(int, QProcess::ExitStatus)));
-    MKisofs->start("genisoimage",QStringList() << "-R" << "-J" << "-o" << fileName << folder  );
+    MKisofs->start("xorrisofs",QStringList() << "-R" << "-J" << "-o" << fileName << folder  );
   }
   else {	
     bool ok;
@@ -67,7 +67,7 @@ void acetoneiso::foldertoiso() {
     MKisofs->setProcessChannelMode(QProcess::MergedChannels);
     connect(MKisofs, SIGNAL(readyReadStandardOutput()), SLOT(updateProgressDisplay_MKisofs() )); 
     connect(MKisofs, SIGNAL(finished(int, QProcess::ExitStatus)), this, SLOT(printOut(int, QProcess::ExitStatus)));
-    MKisofs->start("genisoimage",QStringList()  << "-R" << "-J" << "-V" << text << "-o" << fileName << folder  );
+    MKisofs->start("xorrisofs",QStringList()  << "-R" << "-J" << "-V" << text << "-o" << fileName << folder  );
 
   }
 
