@@ -74,7 +74,7 @@ return;
 	  QString youtube_path = upath.filePath(folder);
 	  //qDebug() << youtube_path;
 	 UTube->setWorkingDirectory(youtube_path);
-      UTube->start( utube_file.fileName(), QStringList() << "-b" << "-t" << text   );
+      UTube->start( utube_file.fileName(), QStringList()  << "-t" << text   );
 
      
   }
@@ -129,7 +129,7 @@ return;
 	  QString youtube_path = upath.filePath(folder);
 	  //qDebug() << youtube_path;
 	 UTube->setWorkingDirectory(youtube_path);
-         UTube->start( utube_file.fileName(), QStringList()  << "-u" << text2 << "-p" << text3 << "-b" << "-t" << text  );
+         UTube->start( utube_file.fileName(), QStringList()  << "-u" << text2 << "-p" << text3  << "-t" << text  );
             
            }
        }
